from ..en_PH import Provider as EnPhAutomotiveProvider


class Provider(EnPhAutomotiveProvider):
    """Implement automotive provider for ``fil_PH`` locale.

    There is no difference from the ``en_PH`` implementation.
    """

    pass
