from .. import Provider as AddressProvider


class Provider(AddressProvider):

    # country names adapted from
    # https://github.com/PyThaiNLP/pythainlp/blob/dev/pythainlp/corpus/countries_th.txt
    countries = (
        "กรีซ",
        "กรีนแลนด์",
        "กวม",
        "กัมพูชา",
        "กัวเดอลุป",
        "กัวเตมาลา",
        "กาตาร์",
        "กานา",
        "กาบอง",
        "กาบูเวร์ดี",
        "กายอานา",
        "กินี-บิสเซา",
        "กินี",
        "เกรเนดา",
        "เกาหลีใต้",
        "เกาหลีเหนือ",
        "เกาะคริสต์มาส",
        "เกาะนอร์ฟอล์ก",
        "เกาะบูเวต",
        "เกาะแมน",
        "เกิร์นซีย์",
        "แกมเบีย",
        "โกตดิวัวร์",
        "คอโมโรส",
        "คอสตาริกา",
        "คาซัคสถาน",
        "คิริบาส",
        "คิวบา",
        "คีร์กีซสถาน",
        "คีลิง",
        "คูเวต",
        "เคนยา",
        "แคนาดา",
        "แคเมอรูน",
        "โครเอเชีย",
        "โคลอมเบีย",
        "จอร์เจีย",
        "จอร์แดน",
        "จาเมกา",
        "จิบูตี",
        "จีน",
        "เจอร์ซีย์",
        "ชาด",
        "ชิลี",
        "ซานมารีโน",
        "ซามัว",
        "ซาอุดีอาระเบีย",
        "ซิมบับเว",
        "ซีเรีย",
        "ซูดาน",
        "ซูรินาม",
        "เซเชลส์",
        "เซนต์คิตส์และเนวิส",
        "เซนต์ลูเซีย",
        "เซนต์วินเซนต์และเกรนาดีนส์",
        "เซนต์เฮเลนา",
        "เซเนกัล",
        "เซอร์เบีย",
        "เซาตูเมและปรินซิปี",
        "เซียร์ราลีโอน",
        "แซ็ง-บาร์เตเลมี",
        "แซ็งบาร์เตเลมี",
        "แซ็ง-มาร์แต็ง",
        "แซ็งมาร์แต็ง",
        "แซงปีแยร์และมีเกอลง",
        "แซมเบีย",
        "โซมาเลีย",
        "ไซปรัส",
        "ญี่ปุ่น",
        "ดอมินีกา",
        "เดนมาร์ก",
        "ตรินิแดดและโตเบโก",
        "ตองกา",
        "ติมอร์-เลสเต",
        "ติมอร์เลสเต",
        "ตุรกี",
        "ตูนิเซีย",
        "ตูวาลู",
        "เติร์กเมนิสถาน",
        "โตเกเลา",
        "โตโก",
        "ไต้หวัน",
        "ทาจิกิสถาน",
        "แทนซาเนีย",
        "ไทย",
        "นครรัฐวาติกัน",
        "นอร์เวย์",
        "นามิเบีย",
        "นาอูรู",
        "นิการากัว",
        "นิวแคลิโดเนีย",
        "นิวซีแลนด์",
        "นีอูเอ",
        "เนเธอร์แลนด์แอนทิลลีส",
        "เนเธอร์แลนด์",
        "เนปาล",
        "ไนจีเรีย",
        "ไนเจอร์",
        "บราซิล",
        "บริติชอินเดียนโอเชียนเทร์ริทอรี",
        "บรูไนดารุสซาลาม",
        "บอตสวานา",
        "บอสเนียและเฮอร์เซโกวีนา",
        "บังกลาเทศ",
        "บัลแกเรีย",
        "บาร์เบโดส",
        "บาห์เรน",
        "บาฮามาส",
        "บุรุนดี",
        "บูร์กินาฟาโซ",
        "เบนิน",
        "เบลเยียม",
        "เบลารุส",
        "เบลีซ",
        "เบอร์มิวดา",
        "โบลิเวีย",
        "ปากีสถาน",
        "ปานามา",
        "ปาปัวนิวกินี",
        "ปารากวัย",
        "ปาเลา",
        "ปาเลสไตน์",
        "เปรู",
        "เปอร์โตริโก",
        "โปรตุเกส",
        "โปแลนด์",
        "ฝรั่งเศส",
        "พม่า",
        "ฟิจิ",
        "ฟินแลนด์",
        "ฟิลิปปินส์",
        "เฟรนช์เกียนา",
        "เฟรนช์โปลินีเซีย",
        "ภูฏาน",
        "มองโกเลีย",
        "มอนต์เซอร์รัต",
        "มอนเตเนโกร",
        "มอริเชียส",
        "มอริเตเนีย",
        "มอลโดวา",
        "มอลตา",
        "มัลดีฟส์",
        "มาเก๊า",
        "มาซิโดเนีย",
        "มาดากัสการ์",
        "มายอต",
        "มาร์ตีนิก",
        "มาลาวี",
        "มาลี",
        "มาเลเซีย",
        "เม็กซิโก",
        "โมซัมบิก",
        "โมนาโก",
        "โมร็อกโก",
        "ไมโครนีเซีย",
        "ยานไมเอน",
        "ยิบรอลตาร์",
        "ยูกันดา",
        "ยูเครน",
        "เยเมน",
        "เยอรมนี",
        "รวันดา",
        "รัสเซีย",
        "เรอูว์นียง",
        "โรมาเนีย",
        "ลักเซมเบิร์ก",
        "ลัตเวีย",
        "ลาว",
        "ลิกเตนสไตน์",
        "ลิทัวเนีย",
        "ลิเบีย",
        "เลโซโท",
        "เลบานอน",
        "ไลบีเรีย",
        "วานูอาตู",
        "วาลลิสและฟุตูนา",
        "เวเนซุเอลา",
        "เวสเทิร์นสะฮารา",
        "เวียดนาม",
        "ศรีลังกา",
        "สกอตแลนด์",
        "สเปน",
        "สฟาลบาร์",
        "สโลวาเกีย",
        "สโลวีเนีย",
        "สวาซิแลนด์",
        "สวิตเซอร์แลนด์",
        "สวีเดน",
        "สหรัฐอเมริกา",
        "สหรัฐอาหรับเอมิเรตส์",
        "สหราชอาณาจักร",
        "สาธารณรัฐคองโก",
        "สาธารณรัฐเช็ก",
        "สาธารณรัฐโดมินิกัน",
        "สิงคโปร์",
        "หมู่เกาะคุก",
        "หมู่เกาะเคย์แมน",
        "หมู่เกาะโคโคส",
        "หมู่เกาะโซโลมอน",
        "หมู่เกาะบริติชเวอร์จิน",
        "หมู่เกาะพิตแคร์น",
        "หมู่เกาะฟอล์กแลนด์",
        "หมู่เกาะแฟโร",
        "หมู่เกาะมาร์แชลล์",
        "อเมริกันซามัว",
        "ออสเตรเลีย",
        "ออสเตรีย",
        "อังกฤษ",
        "อันดอร์รา",
        "อัฟกานิสถาน",
        "อาเซอร์ไบจาน",
        "อาร์เจนตินา",
        "อาร์มีเนีย",
        "อารูบา",
        "อิเควทอเรียลกินี",
        "อิตาลี",
        "อินเดีย",
        "อินโดนีเซีย",
        "อิรัก",
        "อิสราเอล",
        "อิหร่าน",
        "อียิปต์",
        "อุซเบกิสถาน",
        "อุรุกวัย",
        "เอกวาดอร์",
        "เอธิโอเปีย",
        "เอริเทรีย",
        "เอลซัลวาดอร์",
        "เอสโตเนีย",
        "แองกวิลลา",
        "แองโกลา",
        "แอฟริกากลาง",
        "แอฟริกาใต้",
        "แอลจีเรีย",
        "แอลเบเนีย",
        "โอมาน",
        "ไอซ์แลนด์",
        "ไอร์แลนด์",
        "ไอวอรีโคสต์",
        "ฮ่องกง",
        "ฮอนดูรัส",
        "ฮังการี",
        "เฮติ",
    )
